==> hip-runtime-amd-5.4.0-2-x86_64.pkg.tar.zst: opt/rocm/hip/include/hip/amd_detail/amd_warp_functions.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
   */
#ifndef HIP_WRAPPER_INCLUDE_HIP_AMD_DETAIL_AMD_WARP_FUNCTIONS_H
#define HIP_WRAPPER_INCLUDE_HIP_AMD_DETAIL_AMD_WARP_FUNCTIONS_H

#pragma message("This file is deprecated. Use header files from HIP_PATH/include, where HIP_PATH corresponds to HIP install path")
#include "../../../../include/hip/amd_detail/amd_warp_functions.h"








#endif

==> hip-runtime-amd-5.6.0-2-x86_64.pkg.tar.zst: opt/rocm/hip/include/hip/amd_detail/amd_warp_functions.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
   */
#ifndef HIP_WRAPPER_INCLUDE_HIP_AMD_DETAIL_AMD_WARP_FUNCTIONS_H
#define HIP_WRAPPER_INCLUDE_HIP_AMD_DETAIL_AMD_WARP_FUNCTIONS_H

#ifndef ROCM_HEADER_WRAPPER_WERROR
#define ROCM_HEADER_WRAPPER_WERROR 0
#endif
#if ROCM_HEADER_WRAPPER_WERROR  /* ROCM_HEADER_WRAPPER_WERROR 1 */
#error "amd_warp_functions.h has moved to /opt/rocm/include/hip/amd_detail and package include paths have changed. Provide include path as /opt/rocm/include when using cmake packages."
#else      /* ROCM_HEADER_WRAPPER_WERROR 0 */
#if defined(__GNUC__)
#warning "amd_warp_functions.h has moved to /opt/rocm/include/hip/amd_detail and package include paths have changed. Provide include path as /opt/rocm/include when using cmake packages."
#else
#pragma message ("amd_warp_functions.h has moved to /opt/rocm/include/hip/amd_detail and package include paths have changed. Provide include path as /opt/rocm/include when using cmake packages.")
#endif
#endif /* ROCM_HEADER_WRAPPER_WERROR */

#include "../../../../include/hip/amd_detail/amd_warp_functions.h"








#endif
